# Summary of 2 files

## FatalGaudiError

```

Unpack_Hlt2__Event_HLT2_Hlt2PID_...   ERROR Input has empty map of buffers -- can not do anything at this point. Verify HltPackedBufferDecoder configuration
Unpack_Hlt2__Event_HLT2_Hlt2PID_...   ERROR Input has empty map of buffers -- can not do anything at this point. Verify HltPackedBufferDecoder configuration
Unpack_Hlt2__Event_HLT2_Hlt2Trac...   ERROR Input has empty map of buffers -- can not do anything at this point. Verify HltPackedBufferDecoder configuration
Unpack_Hlt2__Event_HLT2_Hlt2Trac...   ERROR Input has empty map of buffers -- can not do anything at this point. Verify HltPackedBufferDecoder configuration
CopyParticles_6e6bdd16                ERROR CopyParticles_6e6bdd16 : Cannot retrieve '/Event/HLT2/Hlt2PID_SMOG2PIDJpsi2MuMumTagged/Particles' from transient store.
CopyParticles_6e6bdd16                ERROR Maximum number of errors ( 'ErrorMax':1) reached.
HLTControlFlowMgr                     FATAL Event failed in Node CopyParticles/CopyParticles_6e6bdd16
HLTControlFlowMgr                      INFO Application return code set to 3
HLTControlFlowMgr                     FATAL Event 60088 on slot 0 failed!
HLTControlFlowMgr                     FATAL *** Too many consecutive failures 1, stopping now ***

```

A unrecognized fatal error occurred in Gaudi.

| Transform | LFN | Job ID | Site | Peak Mem | Log URL(s) | Occurrences |
| --------- | --- | ------ | ---- | -------- | ---------- | ----------- |
| `253065` | `LFN:/lhcb/MC/2024/DST/00249669/0000/00249669_00000248_1.dst` | 974559134 | **LCG.CERN.cern** (3) | 1.7 GiB | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2024%2FLOG%2F00253065%2F0000&task_name=00000071) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2024%2FLOG%2F00253065%2F0000&task_name=00000038) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2024%2FLOG%2F00253065%2F0000&task_name=00000021) | 3 / 3 |
|  | `LFN:/lhcb/MC/2024/DST/00249669/0000/00249669_00000328_1.dst` | 974283441 | **LCG.CERN.cern** (3) | 1.7 GiB | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2024%2FLOG%2F00253065%2F0000&task_name=00000068) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2024%2FLOG%2F00253065%2F0000&task_name=00000036) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2024%2FLOG%2F00253065%2F0000&task_name=00000028) | 3 / 3 |
